@@ -29,9 +29,3 @@ def isASCII(s):
     else:
         raise TypeError('isASCII() requires a string or unicode string')
 
-
-def fetch_url(url):
-    req = urllib2.Request(url)
-    req.add_header('user-agent', 'z3c.pypimirror')
-    return urllib2.urlopen(req)
-
